import LayoutType from '../Models/layoutType';
/**
 * Root class for drivers
 */
export default class Driver {
    /**
     * Name of the device
     */
    DeviceName: string;
    /**
     * Midi In port name
     */
    MidiIn: string;
    /**
     * Midi Out port name
     */
    MidiOut: string;
    /**
     * Dictionary between Node usable commands and Device features
     */
    Dictionary: {
        command: {
            /**
             * SysEx Header
             */
            sysexHeader: Array<number>;
            /**
             * SysEx Footer
             */
            sysexFooter: number;
            /**
             * Select layout command
             */
            selectLayout: number;
            /**
             * Led SysEx command
             */
            ledLightning: number;
            /**
             * Text scolling command
             */
            textScrolling: number;
            /**
             * Brightness level command
             */
            brightness: number;
            /**
             * Programmer or Live mode command
             */
            programmer: number;
            /**
             * Channels for LightningCustomMode
             */
            LightningCustomMode: {
                static: number;
                flashing: number;
                pulsing: number;
            };
        };
        input: {
            onNote: number;
        };
    };
    private queryBuilder;
    /**
     * DriverQuery: feat: setLayout
     * @param {number} layout Layout number
     * @returns {Array<number>}
     */
    setLayout(layout: LayoutType): number[];
    /**
     * DriverQuery: feat: textScrolling
     * @param {number} color Index color
     * @param {string} text Text to display
     * @param {boolean} [shouldLoop=false] Show loop the message
     * @param {number} [speed=7] Speed
     * @returns {Array<number>}
     */
    textScrolling(color: number, text: string, shouldLoop?: boolean, speed?: number): number[];
}
